<?php

/*

Copyright 2014 Dario Curvino (email : d.curvino@tiscali.it)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>
*/

if (!defined('ABSPATH')) {
    exit('You\'re not allowed to see this page');
} // Exit if accessed directly

global $post;

//is post review
wp_nonce_field('yasr_nonce_is_post_review_action', 'yasr_nonce_is_post_review');

//itemType select
wp_nonce_field('yasr_nonce_review_type_action', 'yasr_nonce_review_type');

//get all additional post meta
$saved_data = get_post_meta($post->ID, 'yasr_schema_additional_fields', true);

//if empty, create a new array
if(empty($saved_data)) {
    $saved_data = array();
}

$array_item_type_info = json_decode(YASR_SUPPORTED_SCHEMA_TYPES_ADDITIONAL_FIELDS);

//foreach every supported element, create a nonce field
//and set single element to false if not present in db to avoid undefined
foreach ($array_item_type_info as $item_type) {
    $nonce_action = $item_type . '_nonce_action';
    $nonce_name   = $item_type . '_nonce_name';
    wp_nonce_field($nonce_action, $nonce_name);

    //avoid undefined
    if(!isset($saved_data[$item_type])) {
        $saved_data[$item_type] = false;
    }

}

?>

<div>

    <div id="yasr-schema-metabox-post-is-review">
        <div class="rich-snippet-title">
            <?php _e('Rich snippet options', 'yet-another-stars-rating'); ?>
        </div>
        <?php _e('Is this a review?', 'yet-another-stars-rating'); ?>
        <br />
        <div class="yasr-onoffswitch-big" id="yasr-switcher-post-is-review">
            <input type="checkbox" name="yasr_is_post_review" class="yasr-onoffswitch-checkbox" value='yes'
                   id="yasr-post-is-review-switch" <?php if ($post->yasr_post_is_review === 'yes') echo " checked='checked' "; ?> >
            <label class="yasr-onoffswitch-label" for="yasr-post-is-review-switch">
                <span class="yasr-onoffswitch-inner"></span>
                <span class="yasr-onoffswitch-switch"></span>
            </label>
        </div>
    </div>

    <p>
    <div class="yasr-choose-reviews-types">
        <?php _e("Select ItemType", "yet-another-stars-rating"); ?>
        <br />
        <?php yasr_select_itemtype('yasr-metabox-below-editor-select-schema'); ?>
    </div>

    <div class="yasr-metabox-info-snippet-container" id="yasr-metabox-info-snippet-container" style="display: none;">
        <!--product-->
        <div id="yasr-metabox-info-snippet-container-product"
             class="yasr-metabox-info-snippet-container-child" style="display: none">

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-product-brand">Brand</label>
                <input type="text" name="yasr_product_brand" id="yasr-product-brand"
                       value='<?php echo esc_attr($saved_data['yasr_product_brand']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('The brand of the product.', 'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-product-sku">Sku</label>
                <input type="text" name="yasr_product_sku" id="yasr-product-sku"
                       value='<?php echo esc_attr($saved_data['yasr_product_sku']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('Merchant-specific identifier for product.' , 'yet-another-stars-rating'); ?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-product-global-identifier-select">Global identifiers</label>
                <select name="yasr_product_global_identifier_select" id="yasr-product-global-identifier-select">
                    <?php
                        $array_global_identifiers = array ('gtin8', 'gtin13', 'gtin14', 'mpn', 'isbn');
                        foreach ($array_global_identifiers as $identifier) {
                            if ($saved_data['yasr_product_global_identifier_select'] === $identifier) {
                                echo "<option value=$identifier selected>$identifier</option>";
                            } else {
                                echo "<option value=$identifier>$identifier</option>";
                            }
                        }
                    ?>
                </select>
                <label for="yasr-product-global-identifier-value" style="width: auto; margin-left: 10px;">Value</label>
                <input type="text" name="yasr_product_global_identifier_value" id="yasr-product-global-identifier-value"
                       value='<?php echo esc_attr($saved_data['yasr_product_global_identifier_value']); ?>'
                >
            </div>

            <div class="yasr-itemtype-row-container-description">
                <?php
                    echo sprintf(
                    __('Select global identifier. More info %s here %s', 'yet-another-stars-rating'),
                    '<a href="https://schema.org/Product" target="_blank">','</a>'
                    );
                ?>
            </div>

            <div style="border: 1px dotted #cacaca; width: max-content; margin: 10px; padding: 5px;">
                <div class="yasr-itemtype-row-container-label-input">
                    <label for="yasr-product-price">Price</label>
                    <input type="text" name="yasr_product_price" id="yasr-product-price"
                           value='<?php echo esc_attr($saved_data['yasr_product_price']); ?>'
                    >
                </div>
                <div class="yasr-itemtype-row-container-label-input">
                    <label for="yasr-product-price-currency">Currency</label>
                    <input type="text" name="yasr_product_price_currency" id="yasr-product-price-currency"
                           value='<?php echo esc_attr($saved_data['yasr_product_price_currency']); ?>'
                    >
                </div>
                <div class="yasr-itemtype-row-container-label-input">
                    <label for="yasr-product-price-valid-until">Price Valid Until</label>
                    <input type="text" name="yasr_product_price_valid_until" id="yasr-product-price-valid-until"
                           value='<?php echo esc_attr($saved_data['yasr_product_price_valid_until']); ?>'
                    >
                </div>
                <div class="yasr-itemtype-row-container-label-input">
                    <label for="yasr-product-price-availability">Availability</label>
                    <select name="yasr_product_price_availability" id="yasr-product-price-availability">
                        <?php
                        $array_global_availability = array (
                                'Discontinued', 'InStock', 'InStoreOnly', 'LimitedAvailability',
                                'OnlineOnly', 'OutOfStock', 'PreOrder'. 'PreSale', 'SoldOut');
                        foreach ($array_global_availability as $availability) {
                            if ($saved_data['yasr_product_price_availability'] === $availability) {
                                echo "<option value=$availability selected>$availability</option>";
                            } else {
                                echo "<option value=$availability>$availability</option>";
                            }
                        }
                        ?>
                    </select>
                </div>
                <div class="yasr-itemtype-row-container-label-input">
                    <label for="yasr-product-price-url">Url</label>
                    <input type="text" name="yasr_product_price_url" id="yasr-product-price-url"
                           value='<?php echo esc_attr($saved_data['yasr_product_price_url']); ?>'
                    >
                </div>

                <div class="yasr-itemtype-row-container-description">
                    <?php
                        echo sprintf(
                            __('More info %s here %s', 'yet-another-stars-rating'),
                            '<a href="https://schema.org/Offer" target="_blank">','</a>'
                        );
                    ?>
                </div>

            </div>
        </div>
        <!--End product-->

        <!-- LocalBuisness -->
        <div id="yasr-metabox-info-snippet-container-localbusiness"
             class="yasr-metabox-info-snippet-container-child" style="display: none">

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-localbusiness-address">Address</label>
                <input type="text" name="yasr_localbusiness_address" id="yasr-localbusiness-address"
                       value='<?php echo esc_attr($saved_data['yasr_localbusiness_address']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('The physical location of the business.', 'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-localbusiness-pricerange">PriceRange</label>
                <input type="text" name="yasr_localbusiness_pricerange" id="yasr-localbusiness-pricerange"
                       value='<?php echo esc_attr($saved_data['yasr_localbusiness_pricerange']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('The relative price range of a business, commonly specified by either a numerical range 
                (for example, "$10-15") or a normalized number of currency signs (for example, "$$$")',
                    'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-localbusiness-telephone">Telephone</label>
                <input type="text" name="yasr_localbusiness_telephone" id="yasr-localbusiness-telephone"
                       value='<?php echo esc_attr($saved_data['yasr_localbusiness_telephone']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('A business phone number meant to be the primary contact method for customers.',
                    'yet-another-stars-rating');?>
            </div>
        </div>
        <!-- End LocalBuisness -->

        <!-- Recipe -->
        <div id="yasr-metabox-info-snippet-container-recipe"
             class="yasr-metabox-info-snippet-container-child" style="display: none">

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-cooktime">cookTime</label>
                <input type="text" name="yasr_recipe_cooktime" id="yasr-recipe-cooktime"
                       value='<?php echo esc_attr($saved_data['yasr_recipe_cooktime']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('The time it takes to actually cook the dish in ISO 8601 format. ', 'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-preptime">prepTime</label>
                <input type="text" name="yasr_recipe_preptime" id="yasr-recipe-preptime"
                       value='<?php echo esc_attr($saved_data['yasr_recipe_preptime']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('The length of time it takes to prepare the dish, in ISO 8601 format.',
                    'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-description">description</label>
                <input type="text" name="yasr_recipe_description" id="yasr-recipe-description"
                       value='<?php echo esc_attr($saved_data['yasr_recipe_description']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('A short summary describing the dish.','yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-keywords">keywords</label>
                <input type="text" name="yasr_recipe_keywords" id="yasr-recipe-keywords"
                       value='<?php echo esc_attr($saved_data['yasr_recipe_keywords']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('Other terms for your recipe',
                    'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-nutrition">nutrition</label>
                <input type="text" name="yasr_recipe_nutrition" id="yasr-recipe-nutrition"
                       value='<?php echo esc_attr($saved_data['yasr_recipe_nutrition']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('The number of calories',
                    'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-category">recipeCategory</label>
                <input type="text" name="yasr_recipe_recipecategory" id="yasr-recipe-category"
                       value='<?php echo esc_attr($saved_data['yasr_recipe_recipecategory']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('The type of meal or course your recipe is about',
                    'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-cuisine">recipeCuisine</label>
                <input type="text" name="yasr_recipe_recipecuisine" id="yasr-recipe-cuisine"
                       value='<?php echo esc_attr($saved_data['yasr_recipe_recipecuisine']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('The region associated with your recipe. For example, "Mediterranean", or "American".',
                    'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-ingredient" style="vertical-align: top">recipeIngredient</label>
                <textarea name="yasr_recipe_recipeingredient" rows="4"
                          id="yasr-recipe-ingredient"><?php echo esc_textarea($saved_data['yasr_recipe_recipeingredient']); ?></textarea>
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php
                    echo sprintf(
                        __('A single ingredient used in the recipe, e.g. sugar, flour or garlic. %s 
                            Use return %s to separate the ingredients.',
                            'yet-another-stars-rating'),
                    '<br />',
                    '<strong>(&#8629;)</strong>'
                    );

                ?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-instructions" style="vertical-align: top">recipeInstructions</label>
                <textarea name="yasr_recipe_recipeinstructions" rows="4"
                          id="yasr-recipe-instructions"><?php echo esc_textarea($saved_data['yasr_recipe_recipeinstructions']); ?></textarea>
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php
                    echo sprintf(
                        __('The steps to make dish. Use return %s to separate the steps.',
                            'yet-another-stars-rating'),
                        '<strong>(&#8629;)</strong>'
                    );
                ?>
            </div>

            <div class="yasr-itemtype-row-container-label-input">
                <label for="yasr-recipe-video">Video</label>
                <input type="text" name="yasr_recipe_video" id="yasr-recipe-video"
                       value='<?php echo esc_url($saved_data['yasr_recipe_video']); ?>'
                >
            </div>
            <div class="yasr-itemtype-row-container-description">
                <?php _e('A video depicting the steps to make the dish (URL)',
                    'yet-another-stars-rating');?>
            </div>

            <div class="yasr-itemtype-row-container-description">
                <?php
                echo sprintf(
                    __('More info %s here %s and %s here %s', 'yet-another-stars-rating'),
                    '<a href="https://developers.google.com/search/docs/data-types/recipe" target="_blank">','</a>',
                          '<a href="https://schema.org/Recipe" target="_blank">','</a>'
                );
                ?>
            </div>

        </div>
        <!-- End Recipe -->

    </div>

    <p>

</div>