<?php
/*

Copyright 2014 Dario Curvino (email : d.curvino@tiscali.it)

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>
*/

if (!defined('ABSPATH')) {
    exit('You\'re not allowed to see this page');
} // Exit if accessed directly

/**
 * Class YasrVisitorVotes
 * Print Yasr Visitor Votes
 */
class YasrVisitorVotes extends YasrShortcode {

    protected  $is_singular;
    protected  $unique_id;
    protected  $ajax_nonce_visitor;
    protected  $span_text_after_stars;

    public function __construct($atts, $shortcode_name) {
        parent::__construct($atts, $shortcode_name);

        if (is_singular()) {
            $this->is_singular = 'true';
        } else {
            $this->is_singular = 'false';
        }

        $this->unique_id = str_shuffle(uniqid());
        $this->ajax_nonce_visitor = wp_create_nonce("yasr_nonce_insert_visitor_rating");

        $this->shortcode_html = '<!--Yasr Visitor Votes Shortcode-->';
        $this->shortcode_html .= "<div id='yasr_visitor_votes_$this->post_id' class='yasr-visitor-votes'>";

    }

    public function printVisitorVotesAjax() {

        $htmlid = 'yasr-visitor-votes-rater-' . $this->unique_id ;

        $this->textBeforeAfterStars(false, false);

        $this->shortcode_html  .= "<div id='$htmlid'
                                        class='yasr-rater-stars-visitor-votes'
                                        data-rater-postid='$this->post_id' 
                                        data-rater-starsize='".$this->starSize()."'
                                        data-rater-nonce='$this->ajax_nonce_visitor' 
                                        data-issingular='$this->is_singular'
                                        data-cpt='$this->post_type'
                                  ></div>";

        return $this->returnYasrVisitorVotes(false);

    }


    /**
     * Print the visitor votes shortcode
     *
     * @return string|null
     */
    public function printVisitorVotes() {

        $htmlid = 'yasr-visitor-votes-rater-' . $this->unique_id ;

        //return int
        $stored_votes = YasrDatabaseRatings::getVisitorVotes($this->post_id);

        $number_of_votes = $stored_votes['number_of_votes'];
        if ($number_of_votes > 0) {
            $average_rating = $stored_votes['sum_votes']/$number_of_votes;
        } else {
            $average_rating = 0;
        }

        $average_rating=round($average_rating, 1);

        //if this come from yasr_visitor_votes_readonly...
        if ($this->readonly === true || $this->readonly === "yes") {
            $htmlid = 'yasr-visitor-votes-readonly-rater-'.$this->unique_id;

            $this->shortcode_html = "<div class='yasr-rater-stars-visitor-votes'
                                          id='$htmlid'
                                          data-rating='$average_rating'
                                          data-rater-starsize='".$this->starSize()."'
                                          data-rater-postid='$this->post_id' 
                                          data-rater-readonly='true'>
                                     </div>";

            return $this->shortcode_html;
        }

        $cookie_value = self::checkCookie($this->post_id);
        $stars_enabled = self::starsEnalbed($cookie_value);

        if($stars_enabled === 'true_logged' || $stars_enabled === 'true_not_logged') {
            $this->readonly = 'false'; //Always false if user is logged in
        } else {
            $this->readonly = 'true';
        }

        $this->textBeforeAfterStars($number_of_votes, $average_rating);

        $this->shortcode_html .= "<div id='$htmlid'
                            class='yasr-rater-stars-visitor-votes'
                            data-rater-postid='$this->post_id' 
                            data-rating='$average_rating'
                            data-rater-starsize='".$this->starSize()."'
                            data-rater-readonly='$this->readonly'
                            data-rater-nonce='$this->ajax_nonce_visitor' 
                            data-issingular='$this->is_singular'>
                        </div>";

        return $this->returnYasrVisitorVotes($cookie_value);

    } //end function


    /**
     * Function that checks if cookie exists and set the value
     *
     * @param $post_id int|bool
     * @return int |bool
     */
    public static function checkCookie ($post_id = false) {
        //name of cookie to check
        $yasr_cookiename = 'yasr_visitor_vote_cookie';

        $cookie_value = false;

        if($post_id === false) {
            $post_id = get_the_ID();
        }

        if (isset($_COOKIE[$yasr_cookiename])) {
            $cookie_data = stripslashes($_COOKIE[$yasr_cookiename]);

            //By default, json_decode return an object, true to return an array
            $cookie_data = json_decode($cookie_data, true);

            if (is_array($cookie_data)) {
                foreach ($cookie_data as $value) {
                    $cookie_post_id = (int)$value['post_id'];
                    if ($cookie_post_id === $post_id) {
                        $cookie_value = (int)$value['rating'];
                        //Stop doing foreach, here we've found the rating for current post
                        break;
                    }
                }
            }

            //I've to check $cookie_value !== false before because
            //if $cookie_value is false, $cookie_value < 1 return true (...wtf...)
            if($cookie_value !== false) {
                if ($cookie_value > 5) {
                    $cookie_value = 5;
                } elseif ($cookie_value < 1) {
                    $cookie_value = 1;
                }
            }
            //return int
            return $cookie_value;
        }

        //if cookie is not set (return false)
        return $cookie_value;
    }

    /**
     * Enable or disable stars
     *
     * @param $cookie_value
     *
     * @return string|bool;
     */
    public static function starsEnalbed ($cookie_value) {

        $is_user_logged_in = is_user_logged_in();

        //Logged in user is always able to vote
        if ($is_user_logged_in === true) {
            return 'true_logged';
        }

        //If only logged in users can vote
        if (YASR_ALLOWED_USER === 'logged_only') {
            //IF user is not logged in
            if ($is_user_logged_in === false) {
                return 'false_not_logged';
            }
        }

        //if anonymous are allowed to vote
        if (YASR_ALLOWED_USER === 'allow_anonymous') {
            //I've to check if is user is not logged in
            if ($is_user_logged_in === false) {
                //if cookie !== false means that exists, and user can't vote
                if ($cookie_value !== false) {
                    return 'false_already_voted';
                }
                return 'true_not_logged';
            }
        } //end if YASR_ALLOWED_USER === 'allow_anonymous'

        //this should never happen
        return false;

    }

    /**
     * This function show default (or custom) text depending if rating is allowed or not
     *
     * @param void
     * @return int|bool|void
     */
    public static function showTextBelowStars ($cookie_value) {

        $stars_enabled = self::starsEnalbed($cookie_value);
        $span_bottom_line         = false;
        $span_bottom_line_content = false;

        //If user is logged
        if ($stars_enabled === 'true_logged') {
            //Check if a logged in user has already rated for this post
            $vote_if_user_already_rated = YasrDatabaseRatings::visitorVotesHasUserVoted();

            //If user has already rated
            if ($vote_if_user_already_rated) {
                $span_bottom_line_content = "<span class='yasr-already-voted-text' >"
                                                .__("You've already voted this article with", 'yet-another-stars-rating') .
                                                " $vote_if_user_already_rated" .
                                            "</span>";
            }
        } //true_logged

        elseif ($stars_enabled === 'false_already_voted') {
            $span_bottom_line_content = "<span class='yasr-already-voted-text'>";
            if (YASR_TEXT_BEFORE_STARS === 1 && YASR_CUSTOM_TEXT_USER_VOTED != '') {
                $span_bottom_line_content .= YASR_CUSTOM_TEXT_USER_VOTED;
            } else {
                $span_bottom_line_content .=
                    __('You\'ve already voted this article with', 'yet-another-stars-rating') . ' ' . $cookie_value;
            }
            $span_bottom_line_content .= '</span>';
        }

        //If only logged in users can vote
        elseif ($stars_enabled === 'false_not_logged') {
            $span_bottom_line_content = "<span class='yasr-visitor-votes-must-sign-in'>";
            //if custom text is defined
            if (defined('YASR_CUSTOM_TEXT_MUST_SIGN_IN') && YASR_CUSTOM_TEXT_MUST_SIGN_IN !== '') {
                $span_bottom_line_content .= YASR_CUSTOM_TEXT_MUST_SIGN_IN;
            } else {
                $span_bottom_line_content .= __('You must sign in to vote', 'yet-another-stars-rating');
            }
            $span_bottom_line_content .= '</span>';
        }

        if($span_bottom_line_content !== false) {
            $span_bottom_line = "<span class='yasr-small-block-bold'>";
            //remove \n in the string and use trim
            $span_bottom_line .= $span_bottom_line_content;
            $span_bottom_line .= '</span>';
        }

        return $span_bottom_line;
    }

    /**
     * If enabled in the settings, this function will show the custom text
     * before or after the stars in yasr_visitor_votes
     * Otherwise, shows default text
     *
     * Set $number_of_votes and $average_rating to false if comes from ajax
     *
     * @param  $number_of_votes bool | int
     * @param  $average_rating  bool | int | float
     * @return void
     */
    protected function textBeforeAfterStars ($number_of_votes, $average_rating) {

        //if is not int, and is not false, set to 0
        if(!is_int($number_of_votes) && $number_of_votes !== false) {
            $number_of_votes = 0;
        }

        //if is not int, AND is not float, AND is not FALSE, set to 0
        if(!is_int($average_rating) && !is_float($average_rating) && $average_rating !== false) {
            $average_rating = 0;
        }

        $this->span_text_after_stars = "<span class='yasr-total-average-container'
                                            id='yasr-total-average-text-". $this->unique_id ."'>";

        $number_of_votes_container  = '<span id="yasr-vv-votes-number-container-'. $this->unique_id .'">';
        $average_rating_container   = '<span id="yasr-vv-average-container-'. $this->unique_id .'">';
        $closing_span               = '</span>';

        if (YASR_TEXT_BEFORE_STARS === 1 && YASR_TEXT_BEFORE_VISITOR_RATING != '') {
            $text_before_star = str_replace(
                '%total_count%',
                $number_of_votes_container.$number_of_votes.$closing_span,
                YASR_TEXT_BEFORE_VISITOR_RATING
            );

            $text_before_star = str_replace(
                '%average%',
                $average_rating_container.$average_rating.$closing_span,
                $text_before_star
            );

            $this->shortcode_html   .= "<div class='yasr-container-custom-text-and-visitor-rating'>
                                            <span id='yasr-custom-text-before-visitor-rating'>"
                                       . $text_before_star .
                                       "</span>
                                        </div>";
        }

        if (YASR_TEXT_BEFORE_STARS === 1 && YASR_TEXT_AFTER_VISITOR_RATING != '') {
            $text_after_star = str_replace(
                '%total_count%',
                $number_of_votes_container.$number_of_votes. $closing_span,
                YASR_TEXT_AFTER_VISITOR_RATING
            );

            $text_after_star = str_replace(
                '%average%',
                $average_rating_container.$average_rating.$closing_span,
                $text_after_star
            );
            $this->span_text_after_stars .= $text_after_star;
        }

        //If no customization, default value that has only span after
        else {
            $this->span_text_after_stars .= '['
                                            . __('Total:', 'yet-another-stars-rating')
                                            . '&nbsp;'
                                            . $number_of_votes_container
                                            . $number_of_votes
                                            . $closing_span
                                            . '&nbsp; &nbsp;'
                                            . __('Average:', 'yet-another-stars-rating')
                                            . '&nbsp;'
                                            . $average_rating_container
                                            . $average_rating
                                            . $closing_span
                                            . '/5]';
        }

        $this->span_text_after_stars .= '</span>';

        return;
    }

    /**
     * This function will return the html code for the dashicons
     *
     * @param void
     *
     * @return string
     */
    protected function visitorStats () {
        if (YASR_VISITORS_STATS === 'yes') {
            global $yasr_plugin_imported;

            //default
            $span_dashicon = "<span class='dashicons dashicons-chart-bar yasr-dashicons-visitor-stats'
            data-postid='$this->post_id' id='yasr-total-average-dashicon-$this->post_id'></span>";

            if (is_array($yasr_plugin_imported)) {
                $plugin_import_date = null; //avoid undefined
                if (array_key_exists('wppr', $yasr_plugin_imported)) {
                    $plugin_import_date = $yasr_plugin_imported['wppr']['date'];
                }

                if (array_key_exists('kksr', $yasr_plugin_imported)) {
                    $plugin_import_date = $yasr_plugin_imported['kksr']['date'];
                }

                if (array_key_exists('mr', $yasr_plugin_imported)) {
                    $plugin_import_date = $yasr_plugin_imported['mr']['date'];
                }

                //remove hour from date
                $plugin_import_date=strtok($plugin_import_date,' ');

                $post_date = get_the_date('Y-m-d', $this->post_id);

                //if one of these plugin has been imported and post is older then import,  hide stats
                if ($post_date < $plugin_import_date) {
                    $span_dashicon = "";
                }
            } //End if $yasr_plugin_imported
        } else {
            //Yasr_visitor_stats are disabled
            $span_dashicon = "";
        }
        return $span_dashicon;
    }

    /**
     * Return Yasr Visitor Votes
     *
     * @param $cookie_value int|bool
     * @return string
     */
    protected function returnYasrVisitorVotes ($cookie_value) {
        $span_container_after_stars = "<span id='yasr-visitor-votes-container-after-stars-$this->unique_id'
                                             class='yasr-visitor-votes-after-stars-class'>";

        $this->shortcode_html .= $span_container_after_stars;
        $this->shortcode_html .= $this->visitorStats();
        $this->shortcode_html .= $this->span_text_after_stars;
        if($cookie_value !== false) {
            $this->shortcode_html .= self::showTextBelowStars($cookie_value);
        }
        $this->shortcode_html .= '</span>'; //Close yasr-visitor-votes-after-stars and yasr_visitor_votes
        $this->shortcode_html .= '</div>'; //close all
        $this->shortcode_html .= '<!--End Yasr Visitor Votes Shortcode-->';

        return $this->shortcode_html;
    }
}